
;*********************************************************************************
;* findLine.s:
;*********************************************************************************

;********************************************************************************
;* This file is part of gibl:							*
;*	Gordons Interactive Basic Language                                      *
;********************************************************************************
;*    A Tiny Basic for the 6502 inspired by the NIBL Tiny Basic interpreter;	*
;*    "National Industrial Basic Language" originally for the INS8060 SC/MP	*
;*    system.									*
;*										*
;*    gibl is distributed under a "Source Available" license.			*
;*	It is NOT Open source and must not be treated as such.			*
;*										*
;*    See the file LICENSE for details.						*
;*										*
;*    gibl is Copyright (c) 2023 by Gordon Henderson				*
;********************************************************************************

	.macpack	generic

	.include	"data.h"
	.include	"ilUtils.h"

	.include	"findLine.h"


;********************************************************************************
;* findLine:
;*	Search the program space for a line number stored in lo,hi.
;*	Set the cursor to the address in the program whos line is > or = to
;*	the one we're searching for.
;*	Also store in lablLo and lablHi.
;*	Set the sign bit of labHi if exact line is NOT found.
;*
;* Note: Program line numbers are stored High byte first!
;********************************************************************************

.proc	findLine

; Set cursor to start of text

	jsr	resetCursor

findLineLoop:
	ldy	#0
	lda	(cursor),y		; Check high byte ...
	cmp	#$FF			; ... Run off the end?
	beq	higher

; Test for exact

	lda	(cursor),y		; High
	cmp	hi
	bne	testGT
	iny
	lda	(cursor),y		; Low
	cmp	lo
	bne	testGT

; We have an exact match, 
;	Save address in lablLo and lablHi
;	... and return

saveAddr:
	lda	cursorL
	sta	lablLo
	lda	cursorH
	sta	lablHi
	rts

testGT:
	lda	hi		; Get high byte
	ldy	#0
	cmp	(cursor),y
	bcc	higher
	bne	lower
	lda	lo		; Get low byte
	iny
	cmp	(cursor),y
	bcc	higher		; if >=

; Lower - move to the next line

lower:
	ldy	#2
	lda	(cursor),y		; Get line length byte
	clc
	adc	cursorL
	sta	cursorL
	lda	cursorH
	adc	#0
	sta	cursorH
	jmp	findLineLoop

higher:

; Save address in lablLo and lablHi

	jsr	saveAddr

; but it's inexact, so set top bit of the line number
;	before returning

	lda	lablHi
	ora	#$80
	sta	lablHi
	rts
.endproc
